errors = {
    'unsupported_platform_for_module': 200,
    'wheels_key_missing': 201,
    'unsupported_url_type': 202,
    'nonexistent_source_path': 203,
    'archive_already_exists': 204,
    'directory_already_exists': 205,
    'validation_failed': 206,
    'failed_to_wheel': 207,
    'failed_to_retrieve_index_info': 208,
    'failed_to_create_virtualenv': 209,
    'cannot_exclude_main_package': 210,
    'failed_to_install_package': 211
}
